@@ -129,9 +129,7 @@ def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters:
 
     utils.check_url(args['url'])
 
-    now = datetime.datetime.now().time()
-    time_str = now.strftime("%Y%m%d-%H%M%S")
-    step_file =  'step_trace_' + time_str + 'json'
+    step_file = conf.get('step_trace', None)
 
     min_rounds = 1
     if type(rounds) == tuple:
@@ -176,8 +174,9 @@ def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters:
     step_trace['steps'] = copy.deepcopy(steps)
     step_trace['args'] = args
 
-    with open(step_file, "w") as fo:
-        json.dump(fo, step_trace)
+    if step_file is not None :
+        with open(step_file, "w") as fo:
+            json.dump(step_trace, fo)
 
     # best round cost
     best_round_cost =  np.inf
@@ -250,12 +249,14 @@ def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters:
             print('\n     Step summary, best particle values: {} '.format(pos))
 
             key = "r{}s{}".format(r + 1, s + 1)
+            step_trace[key] = {}
             step_trace[key]['time'] =  str(datetime.datetime.now())
             step_trace[key]['best_costs'] = best_cost
             step_trace[key]['steps'] = copy.deepcopy(steps)
 
-            with open(step_file, "w") as fo:
-                json.dump(fo, step_trace)
+            if step_file is not None :
+                with open(step_file, "w") as fo:
+                    json.dump(step_trace, fo)
 
             # print(json.dumps(steps, sort_keys=False, indent=2))
 
@@ -272,12 +273,14 @@ def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters:
               .format(best_round_cost, rel_round_tol, rtol))
 
         key = "r{}".format(r + 1)
+        step_trace[key] = {}
         step_trace[key]['time'] = str(datetime.datetime.now())
         step_trace[key]['round_cost'] = round_cost
         step_trace[key]['best_costs'] = best_cost
         step_trace[key]['improvements'] = no_improvement
-        with open(step_file, "w") as fo:
-            json.dump(fo, step_trace)
+        if step_file is not None :
+            with open(step_file, "w") as fo:
+                json.dump(step_trace, fo)
 
         if (r + 1 >= min_rounds) and 0 <= rel_round_tol < rtol:
             r_below += 1
@@ -303,8 +306,9 @@ def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters:
     step_trace['end'] = str(datetime.datetime.now())
     step_trace['time'] = elapsed
 
-    with open(step_file, "w") as fo:
-        json.dump(fo, step_trace)
+    if step_file is not None :
+        with open(step_file, "w") as fo:
+            json.dump(step_trace, fo)
 
     return optimizer, step_trace
 
